@@ -8,7 +8,7 @@ package IO::Async::Connector;
 use strict;
 use warnings;
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 use POSIX qw( EINPROGRESS );
 use Socket qw( SOL_SOCKET SO_ERROR );
@@ -333,9 +333,12 @@ method.
 
 =back
 
-It is sometimes necessary to pass the C<socktype> hint to the resolver when
-resolving the host/service names into an address, as some OS's C<getaddrinfo>
-functions require this hint.
+It is necessary to pass the C<socktype> hint to the resolver when resolving
+the host/service names into an address, as some OS's C<getaddrinfo> functions
+require this hint. A warning is emitted if neither C<socktype> nor C<protocol>
+hint is defined when performing a C<getaddrinfo> lookup. To avoid this warning
+while still specifying no particular C<socktype> hint (perhaps to invoke some
+OS-specific behaviour), pass C<0> as the C<socktype> value.
 
 =cut
 
@@ -378,6 +381,12 @@ sub connect
    my %gai_hints;
    exists $params{$_} and $gai_hints{$_} = $params{$_} for qw( family socktype protocol flags );
 
+   if( exists $params{host} or exists $params{local_host} or exists $params{local_port} ) {
+      # We'll be making a ->getaddrinfo call
+      defined $gai_hints{socktype} or defined $gai_hints{protocol} or
+         carp "Attempting to ->connect without either 'socktype' or 'protocol' hint is not portable";
+   }
+
    my @localaddrs;
    my @peeraddrs;
 
@@ -471,11 +480,6 @@ sub connect
    );
 }
 
-# Keep perl happy; keep Britain tidy
-1;
-
-__END__
-
 =head1 EXAMPLES
 
 =head2 Passing Plain Socket Addresses
@@ -511,3 +515,7 @@ This example shows another way to connect to a UNIX socket at F<echo.sock>.
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
+0x55AA;
