@@ -1,18 +1,18 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011 -- leonerd@leonerd.org.uk
 
 package IO::Async::FileStream;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.60_004';
+our $VERSION = '0.40';
 
 use base qw( IO::Async::Stream );
 
-use IO::Async::File;
+use IO::Async::Timer::Periodic;
 
 use Carp;
 use Fcntl qw( SEEK_SET SEEK_CUR );
@@ -26,7 +26,7 @@ C<IO::Async::FileStream> - read the tail of a file
  use IO::Async::FileStream;
 
  use IO::Async::Loop;
- my $loop = IO::Async::Loop->new;
+ my $loop = IO::Async::Loop->new();
 
  open my $logh, "<", "var/logs/daemon.log" or
     die "Cannot open logfile - $!";
@@ -52,7 +52,7 @@ C<IO::Async::FileStream> - read the tail of a file
 
  $loop->add( $filestream );
 
- $loop->run;
+ $loop->loop_forever;
 
 =head1 DESCRIPTION
 
@@ -67,9 +67,6 @@ used as the C<transport> for an C<IO::Async::Protocol::Stream> object.
 
 It will not support writing.
 
-To watch a file, directory, or other filesystem entity for updates of other
-properties, such as C<mtime>, see also L<IO::Async::File>.
-
 =cut
 
 =head1 EVENTS
@@ -116,14 +113,14 @@ sub _init
 
    $self->SUPER::_init( $params );
 
+   $self->add_child( $self->{timer} = IO::Async::Timer::Periodic->new(
+      interval => 2,
+      on_tick => $self->_capture_weakself( 'on_tick' ),
+   ) );
+
    $params->{close_on_read_eof} = 0;
 
    $self->{last_size} = undef;
-
-   $self->add_child( $self->{file} = IO::Async::File->new(
-      on_devino_changed => $self->_replace_weakself( 'on_devino_changed' ),
-      on_size_changed   => $self->_replace_weakself( 'on_size_changed' ),
-   ) );
 }
 
 =head1 PARAMETERS
@@ -134,13 +131,6 @@ C<IO::Async::Stream>.
 
 =over 8
 
-=item filename => STRING
-
-Optional. If supplied, watches the named file rather than the filehandle given
-in C<read_handle>. The file will be opened by the constructor, and then
-watched for renames. If the file is renamed, the new filename is opened and
-tracked similarly after closing the previous file.
-
 =item interval => NUM
 
 Optional. The interval in seconds to poll the filehandle using C<stat(2)>
@@ -161,15 +151,7 @@ sub configure
    }
 
    foreach (qw( interval )) {
-      $self->{file}->configure( $_ => delete $params{$_} ) if exists $params{$_};
-   }
-   if( exists $params{filename} ) {
-      $self->{file}->configure( filename => delete $params{filename} );
-      $params{read_handle} = $self->{file}->handle;
-   }
-   elsif( exists $params{read_handle} ) {
-      $self->{file}->configure( handle => delete $params{read_handle} );
-      $params{read_handle} = $self->{file}->handle;
+      $self->{timer}->configure( $_ => delete $params{$_} ) if exists $params{$_};
    }
 
    croak "Cannot have a write_handle in a ".ref($self) if defined $params{write_handle};
@@ -177,12 +159,7 @@ sub configure
    $self->SUPER::configure( %params );
 
    if( $self->read_handle and !defined $self->{last_size} ) {
-      my $size = (stat $self->read_handle)[7];
-
-      $self->{last_size} = $size;
-
-      local $self->{running_initial} = 1;
-      $self->maybe_invoke_event( on_initial => $size );
+      $self->_do_initial;
    }
 }
 
@@ -197,10 +174,10 @@ sub _watch_read
    my ( $want ) = @_;
 
    if( $want ) {
-      $self->{file}->start if !$self->{file}->is_running;
+      $self->{timer}->start if !$self->{timer}->is_running;
    }
    else {
-      $self->{file}->stop;
+      $self->{timer}->stop;
    }
 }
 
@@ -212,28 +189,34 @@ sub _watch_write
    croak "Cannot _watch_write in " . ref($self) if $want;
 }
 
-sub on_devino_changed
+sub _do_initial
 {
-   my $self = shift or return;
+   my $self = shift;
 
-   $self->{renamed} = 1;
-   $self->debug_printf( "read tail of old file" );
-   $self->read_more;
+   my $size = (stat $self->read_handle)[7];
+
+   $self->{last_size} = $size;
+
+   local $self->{running_initial} = 1;
+   $self->maybe_invoke_event( on_initial => $size );
 }
 
-sub on_size_changed
+sub on_tick
 {
-   my $self = shift or return;
-   my ( $size ) = @_;
+   my $self = shift;
+
+   my $size = (stat $self->read_handle)[7];
 
    if( $size < $self->{last_size} ) {
       $self->maybe_invoke_event( on_truncated => );
       $self->{last_pos} = 0;
    }
+   elsif( $size == $self->{last_size} ) {
+      return;
+   }
 
    $self->{last_size} = $size;
 
-   $self->debug_printf( "read_more" );
    $self->read_more;
 }
 
@@ -248,21 +231,7 @@ sub read_more
    $self->{last_pos} = sysseek( $self->read_handle, 0, SEEK_CUR ); # == systell
 
    if( $self->{last_pos} < $self->{last_size} ) {
-      $self->loop->later( sub { $self->read_more } );
-   }
-   elsif( $self->{renamed} ) {
-      $self->debug_printf( "reopening for rename" );
-
-      $self->{last_size} = 0;
-
-      if( $self->{last_pos} ) {
-         $self->maybe_invoke_event( on_truncated => );
-         $self->{last_pos} = 0;
-         $self->loop->later( sub { $self->read_more } );
-      }
-
-      $self->configure( read_handle => $self->{file}->handle );
-      undef $self->{renamed};
+      $self->get_loop->later( sub { $self->read_more } );
    }
 }
 
@@ -394,6 +363,11 @@ sub seek_to_last
 
 =item *
 
+Support opening a file by name instead of taking an already-open filehandle.
+With that comes the option to track it for renames too.
+
+=item *
+
 Move the actual file update watching code into C<IO::Async::Loop>, possibly as
 a new watch/unwatch method pair C<watch_file>.
 
