@@ -43,7 +43,7 @@ sub enqueue
    my ( %params ) = @_;
 
    my $code = delete $params{code};
-   ref $code eq "CODE" or croak "Expected 'code' to be a CODE reference";
+   ref $code or croak "Expected 'code' to be a reference";
 
    defined $params{time} or croak "Expected 'time'";
    my $time = $params{time};
@@ -107,9 +107,6 @@ sub fire
    return $count;
 }
 
-# Keep perl happy; keep Britain tidy
-1;
-
 package # hide from CPAN
   IO::Async::Internals::TimeQueue::Elem;
 
@@ -153,5 +150,4 @@ sub cmp
    $self->time <=> $other->time;
 }
 
-# Keep perl happy; keep Britain tidy
-1;
+0x55AA;
