@@ -8,7 +8,7 @@ package IO::Async::Notifier;
 use strict;
 use warnings;
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -39,9 +39,12 @@ Usually not directly used by a program, but one valid use case may be:
        on_read => sub {
           my $self = shift;
           my ( $buffref, $eof ) = @_;
-          $$buffref =~ s/^(.*)\n// or return 0;
-          print "You said $1\n";
-          return 1;
+
+          while( $$buffref =~ s/^(.*)\n// ) {
+             print "You said $1\n";
+          }
+
+          return 0;
        },
     )
  );
@@ -458,6 +461,10 @@ the CODE ref internally for efficiency.
 
 The C<$code> argument may also be a plain string, which will be used as a
 method name; the returned CODE ref will then invoke that method on the object.
+In this case the method name is stored symbolically in the returned CODE
+reference, and dynamically dispatched each time the reference is invoked. This
+allows it to follow code reloading, dynamic replacement of class methods, or
+other similar techniques.
 
 If the C<$mref> CODE reference is being stored in some object other than the
 one it refers to, remember that since the Notifier is only weakly captured, it
@@ -480,21 +487,24 @@ sub _capture_weakself
 
    if( !ref $code ) {
       my $class = ref $self;
-      my $coderef = $self->can( $code ) or
+      # Don't save this coderef, or it will break dynamic method dispatch,
+      # which means code reloading, dynamic replacement, or other funky
+      # techniques stop working
+      $self->can( $code ) or
          croak qq(Can't locate object method "$code" via package "$class");
-
-      $code = $coderef;
    }
 
    weaken $self;
 
    return sub {
+      my $cv = ref( $code ) ? $code : $self->can( $code );
+
       if( HAS_BROKEN_TRAMPOLINES ) {
-         return $code->( $self, @_ );
+         return $cv->( $self, @_ );
       }
       else {
          unshift @_, $self;
-         goto &$code;
+         goto &$cv;
       }
    };
 }
@@ -521,6 +531,7 @@ function's arguments.
 
 The C<$code> argument may also be a plain string, which will be used as a
 method name; the returned CODE ref will then invoke that method on the object.
+As with C<_capture_weakself> this is stored symbolically.
 
 As with C<_capture_weakself>, care should be taken against Notifier
 destruction if the C<$mref> CODE reference is stored in some other object.
@@ -533,24 +544,25 @@ sub _replace_weakself
    my ( $code ) = @_;   # actually bare method names work too
 
    if( !ref $code ) {
+      # Don't save this coderef, see _capture_weakself for why
       my $class = ref $self;
-      my $coderef = $self->can( $code ) or
+      $self->can( $code ) or
          croak qq(Can't locate object method "$code" via package "$class");
-
-      $code = $coderef;
    }
 
    weaken $self;
 
    return sub {
+      my $cv = ref( $code ) ? $code : $self->can( $code );
+
       if( HAS_BROKEN_TRAMPOLINES ) {
-         return $code->( $self, @_[1..$#_] );
+         return $cv->( $self, @_[1..$#_] );
       }
       else {
          # Don't assign to $_[0] directly or we will change caller's first argument
          shift @_;
          unshift @_, $self;
-         goto &$code;
+         goto &$cv;
       }
    };
 }
@@ -655,11 +667,10 @@ sub maybe_invoke_event
    return [ $code->( $self, @args ) ];
 }
 
-# Keep perl happy; keep Britain tidy
-1;
-
-__END__
-
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
+0x55AA;
